;;; custom-load.el --- automatically extracted custom dependencies

;;; Code:

(autoload 'custom-add-loads "cus-load")

(custom-add-loads 'hypermedia '("dictionary"))
(custom-add-loads 'dictionary '("dictionary"))
(custom-add-loads 'dictionary-proxy '("dictionary"))

;;; custom-load.el ends here
